==> pleiades_1.1.0.zip: src/jp/sourceforge/mergedoc/pleiades/aspect/resource/NotFoundLog.java <==
/*
 * Copyright (c) 2005- Shinji Kashihara.
 * All rights reserved. This program are made available under
 * the terms of the Eclipse Public License v1.0 which accompanies
 * this distribution, and is available at epl-v10.html.
 */
package jp.sourceforge.mergedoc.pleiades.aspect.resource;

import java.io.BufferedOutputStream;
import java.io.BufferedReader;
import java.io.File;
import java.io.FileOutputStream;
import java.io.FileReader;
import java.io.IOException;
import java.io.PrintStream;
import java.util.HashSet;
import java.util.Set;
import java.util.regex.Pattern;

import jp.sourceforge.mergedoc.pleiades.aspect.Agent;
import jp.sourceforge.mergedoc.pleiades.io.FileSystem;
import jp.sourceforge.mergedoc.pleiades.log.Logger;

import org.apache.commons.io.IOUtils;

/**
 * |vpeB[ɗvfȂꍇ̏o͂邽߂̃K[łB
 * <p>
 * @author C/pHeR
 */
public class NotFoundLog {
	
	/** K[ */
	private static final Logger log = Logger.getLogger(NotFoundLog.class);
	
	/** 󖳂Oo̓t@C */
	private static final File NOT_FOUND_LOG_FILE_NAME =
		new File(Agent.configurationPath, "translation-notfound.properties");
	
	/** 󖳂Oo͂珜OvfXgt@C */
	private static final File EXCLUDE_LIST_FILE_NAME =
		FileSystem.getResourceFile("translation-notfound-exclud.list");
	
	/** 󖳂K[CX^X */
	private static NotFoundLog notFoundLog;
	
	/** 󖳂K[CX^X̏ */
	static {
		if (Agent.getInstance().getAgentOption().isEnabledNotFoundLog()) {
			notFoundLog = new NotFoundLog();
			notFoundLog.init();
		} else {
			notFoundLog = new NotFoundLog() {
				public void println(String enValueNonMnemonic) {
				}
			};
		}
	}
	
	/** 󖳂K[o͂珜Ovf̃Zbg */
	private Set<String> excludSet;
	
	/** 󖳂K[o͂珜Ovf̃ZbgiK\j */
	private Set<Pattern> excludPatternSet;
	
	/** 󖳂K[ɏo͍ς݂̗vfio͗}~pj */
	private Set<String> loggedSet;
	
	/** t@C PrintStream */
	private PrintStream out;
	
	/**
	 * CX^Xł܂B
	 */
	private NotFoundLog() {
	}
	
	/**
	 * 󖳂K[̃CX^X擾܂B
	 * <p>
	 * @return 󖳂K[̃CX^X
	 */
	public static NotFoundLog getInstance() {
		return notFoundLog;
	}
	
	/**
	 * ܂B
	 */
	private void init() {
		
		excludSet = new HashSet<String>();
		excludPatternSet = new HashSet<Pattern>();
		loggedSet = new HashSet<String>();
		
		BufferedReader in = null;
		try {
			in = new BufferedReader(new FileReader(EXCLUDE_LIST_FILE_NAME));
			
			for (String line; (line = in.readLine()) != null;) {
				if (!line.startsWith("#")) {
					String str = line.replaceAll("\\\\n", "\n");
					String prefix = "%REGEX%";
					if (str.startsWith(prefix)) {
						Pattern pattern = Pattern.compile(str.replaceFirst(prefix, ""));
						excludPatternSet.add(pattern);
					} else {
						excludSet.add(str);
					}
				}
			}
			
		} catch (IOException e) {
			String msg = "󖳂Oo͏OXg[hł܂łB";
			log.fatal(msg, e);
			throw new RuntimeException(msg, e);
			
		} finally {
			IOUtils.closeQuietly(in);
		}
		
		try {
			out = new PrintStream(
					new BufferedOutputStream(new FileOutputStream(NOT_FOUND_LOG_FILE_NAME)),
					true);
		} catch (IOException e) {
			String msg = "󖳂OC^[𐶐ł܂łB";
			log.fatal(msg, e);
			throw new RuntimeException(msg, e);
		}
		
		// VM Vbg_EEtbNƂăt@C PrintStream ̃N[Yo^
		Runtime.getRuntime().addShutdownHook(new Thread() {
			public void run() {
				PrintStream out = NotFoundLog.getInstance().out;
				IOUtils.closeQuietly(out);
			}
		});
	}
	
	/**
	 * w肳ꂽvfOo͂܂B
	 * <p>
	 * @param enValueNonMnemonic j[jbN܂܂Ȃpꃊ\[X
	 */
	public void println(String enValueNonMnemonic) {
		
		if (loggedSet.contains(enValueNonMnemonic)) {
			return;
		}
		if (excludSet.contains(enValueNonMnemonic)) {
			return;
		}
		for (Pattern pattern : excludPatternSet) {
			if (pattern.matcher(enValueNonMnemonic).matches()) {
				return;
			}
		}
		loggedSet.add(enValueNonMnemonic);
		
		String key = enValueNonMnemonic
			.replaceAll("[ :=#!\t\\\\]", "\\\\$0")
			.replaceAll("\r", "\\\\r")
			.replaceAll("\n", "\\\\n");
		
		String value = enValueNonMnemonic
			.replaceAll("\n", " ");
		
		if (key.matches("(?s).*\\p{Alpha}{2}.*")) {
			out.println(key + "=" + value);
		}
	}
}

==> pleiades_1.2.0.zip: src/jp/sourceforge/mergedoc/pleiades/aspect/resource/NotFoundLog.java <==
/*
 * Copyright (c) 2005- Shinji Kashihara.
 * All rights reserved. This program are made available under
 * the terms of the Eclipse Public License v1.0 which accompanies
 * this distribution, and is available at epl-v10.html.
 */
package jp.sourceforge.mergedoc.pleiades.aspect.resource;

import java.io.BufferedOutputStream;
import java.io.BufferedReader;
import java.io.File;
import java.io.FileOutputStream;
import java.io.FileReader;
import java.io.IOException;
import java.io.PrintStream;
import java.util.HashSet;
import java.util.Set;
import java.util.regex.Pattern;

import jp.sourceforge.mergedoc.pleiades.aspect.Agent;
import jp.sourceforge.mergedoc.pleiades.log.Logger;
import jp.sourceforge.mergedoc.pleiades.util.FileSystem;

import org.apache.commons.io.IOUtils;

/**
 * |vpeB[ɗvfȂꍇ̏o͂邽߂̃K[łB
 * <p>
 * @author C/pHeR
 */
public class NotFoundLog {
	
	/** K[ */
	private static final Logger log = Logger.getLogger(NotFoundLog.class);
	
	/** 󖳂Oo̓t@C */
	private static final File NOT_FOUND_LOG_FILE_NAME =
		new File(Agent.configurationPath, "translation-notfound.properties");
	
	/** 󖳂Oo͂珜OvfXgt@C */
	private static final File EXCLUDE_LIST_FILE_NAME =
		FileSystem.getResourceFile("translation-notfound-exclud.list");
	
	/** 󖳂K[CX^X */
	private static NotFoundLog notFoundLog;
	
	/** 󖳂K[CX^X̏ */
	static {
		if (Agent.getInstance().getAgentOption().isEnabledNotFoundLog()) {
			notFoundLog = new NotFoundLog();
			notFoundLog.init();
		} else {
			notFoundLog = new NotFoundLog() {
				public void println(String enValueNonMnemonic) {
				}
			};
		}
	}
	
	/** 󖳂K[o͂珜Ovf̃Zbg */
	private Set<String> excludSet;
	
	/** 󖳂K[o͂珜Ovf̃ZbgiK\j */
	private Set<Pattern> excludPatternSet;
	
	/** 󖳂K[ɏo͍ς݂̗vfio͗}~pj */
	private Set<String> loggedSet;
	
	/** t@C PrintStream */
	private PrintStream out;
	
	/**
	 * CX^Xł܂B
	 */
	private NotFoundLog() {
	}
	
	/**
	 * 󖳂K[̃CX^X擾܂B
	 * <p>
	 * @return 󖳂K[̃CX^X
	 */
	public static NotFoundLog getInstance() {
		return notFoundLog;
	}
	
	/**
	 * ܂B
	 */
	private void init() {
		
		excludSet = new HashSet<String>();
		excludPatternSet = new HashSet<Pattern>();
		loggedSet = new HashSet<String>();
		
		BufferedReader in = null;
		try {
			in = new BufferedReader(new FileReader(EXCLUDE_LIST_FILE_NAME));
			
			for (String line; (line = in.readLine()) != null;) {
				if (!line.startsWith("#")) {
					String str = line.replaceAll("\\\\n", "\n");
					String prefix = "%REGEX%";
					if (str.startsWith(prefix)) {
						Pattern pattern = Pattern.compile(str.replaceFirst(prefix, ""));
						excludPatternSet.add(pattern);
					} else {
						excludSet.add(str);
					}
				}
			}
			
		} catch (IOException e) {
			String msg = "󖳂Oo͏OXg[hł܂łB";
			log.fatal(msg, e);
			throw new RuntimeException(msg, e);
			
		} finally {
			IOUtils.closeQuietly(in);
		}
		
		try {
			out = new PrintStream(
					new BufferedOutputStream(new FileOutputStream(NOT_FOUND_LOG_FILE_NAME)),
					true);
		} catch (IOException e) {
			String msg = "󖳂OC^[𐶐ł܂łB";
			log.fatal(msg, e);
			throw new RuntimeException(msg, e);
		}
		
		// VM Vbg_EEtbNƂăt@C PrintStream ̃N[Yo^
		Runtime.getRuntime().addShutdownHook(new Thread() {
			public void run() {
				PrintStream out = NotFoundLog.getInstance().out;
				IOUtils.closeQuietly(out);
			}
		});
	}
	
	/**
	 * w肳ꂽvfOo͂܂B
	 * <p>
	 * @param enValueNonMnemonic j[jbN܂܂Ȃpꃊ\[X
	 */
	public void println(String enValueNonMnemonic) {
		
		if (loggedSet.contains(enValueNonMnemonic)) {
			return;
		}
		if (excludSet.contains(enValueNonMnemonic)) {
			return;
		}
		for (Pattern pattern : excludPatternSet) {
			if (pattern.matcher(enValueNonMnemonic).matches()) {
				return;
			}
		}
		loggedSet.add(enValueNonMnemonic);
		
		String key = enValueNonMnemonic
			.replaceAll("[ :=#!\t\\\\]", "\\\\$0")
			.replaceAll("\r", "\\\\r")
			.replaceAll("\n", "\\\\n");
		
		String value = enValueNonMnemonic
			.replaceAll("\n", " ");
		
		if (key.matches("(?s).*\\p{Alpha}{2}.*")) {
			out.println(key + "=" + value);
		}
	}
}
